@@ -8,9 +8,10 @@ import createTestDirectory from "./helpers/createTestDirectory";
 const outputDir = path.join(__dirname, "output/options");
 const babelLoader = path.join(__dirname, "../lib");
 const globalConfig = {
+  mode: "development",
   entry: path.join(__dirname, "fixtures/basic.js"),
   module: {
-    loaders: [
+    rules: [
       {
         test: /\.jsx?/,
         loader: babelLoader,
@@ -38,7 +39,7 @@ test.cb("should interpret options given to the loader", t => {
       path: t.context.directory,
     },
     module: {
-      loaders: [
+      rules: [
         {
           test: /\.jsx?/,
           loader: babelLoader + "?presets[]=env",
@@ -48,8 +49,10 @@ test.cb("should interpret options given to the loader", t => {
     },
   });
 
-  webpack(config, err => {
+  webpack(config, (err, stats) => {
     t.is(err, null);
+    t.is(stats.compilation.errors.length, 0);
+    t.is(stats.compilation.warnings.length, 0);
 
     fs.readdir(outputDir, (err, files) => {
       t.is(err, null);
