@@ -10,13 +10,6 @@ test("should find the .babelrc file", t => {
   t.is(result, path.join(__dirname, "fixtures/babelrc-test/.babelrc"));
 });
 
-test("should find the .babelrc.js config", t => {
-  const start = path.join(__dirname, "fixtures/babelrc-test/1/2/5/4");
-  const result = resolveRc(fs, start);
-
-  t.is(result, path.join(__dirname, "fixtures/babelrc-test/1/2/5/.babelrc.js"));
-});
-
 test("should find the package.json babel config", t => {
   const start = path.join(__dirname, "fixtures/package-test");
   const result = resolveRc(fs, start);
